SnackbarColors class

Pre-defined color schemes for different snackbar types.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

errorBackground → const Color
Error colors
errorText → const Color
Error text
infoBackground → const Color
Info colors
infoText → const Color
Info text
normalBackground → const Color
Normal/Default colors
normalText → const Color
Normal/Default text
successBackground → const Color
Success colors
successText → const Color
Success text
warningBackground → const Color
Warning colors
warningText → const Color
Warning text