SnackbarKitConfig class

Global configuration for SnackbarKit widgets.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

defaultBehavior SnackBarBehavior
Default behavior for snackbars (default: floating).
getter/setter pair
defaultDuration Duration
Default duration for snackbars (default: 3 seconds).
getter/setter pair
defaultMargin EdgeInsets
Default margin for snackbars (default: 20px all sides).
getter/setter pair
defaultPosition SnackbarPosition
Default position for snackbars (default: top).
getter/setter pair
progressIndicatorHeight double
Height of the progress indicator (default: 4.0).
getter/setter pair
showCloseButton bool
Whether to show close button on snackbars (default: false).
getter/setter pair
showProgressIndicator bool
Whether to show progress indicator on snackbars (default: true).
getter/setter pair

Static Methods

configure({Duration? defaultDuration, SnackBarBehavior? defaultBehavior, EdgeInsets? defaultMargin, bool? showCloseButton, bool? showProgressIndicator, double? progressIndicatorHeight, SnackbarPosition? defaultPosition}) → void
Configures global defaults for all SnackbarKit instances.